==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/admin.py <==
# -*- coding: utf-8 -*-

import os
import datetime

from django.contrib import admin
from django.utils.translation import ugettext as _
from django import forms
from django.conf import settings
from django.core.urlresolvers import reverse

from jmb.core.admin.options import ExtendibleModelAdmin, OrderedModelAdmin
from jmb.core.forms.widgets import DateWidget
from django.conf.urls.defaults import patterns, url

from jmb.organization.models import Organization
from jmb.fax.models import Fax, Device, FaxNumber, FaxPermission, Document, Cover
from jmb.fax import views as fax_views, forms as fax_forms

class FaxAdmin(ExtendibleModelAdmin):
    form = fax_forms.FaxForm
    list_title = _('List Fax')
    list_display = (
        'get_status', 'get_pages', 'sender', 'recipient', 'recipient_number', 'get_subject',
        'submitter', 'date_create', 'device',
        'get_notify_group', 'get_read', 'get_report', 'get_cover',
        'get_edit_icon', 'get_delete_icon'
    )
    advanced_search_fields = (
        ('status', 'subject__icontains'),
        ('recipient_number__icontains', 'recipient__icontains'),
        ('sender_number__icontains', 'sender__icontains'),
        ('date_sent__gte', 'date_sent__lte'),
    )

    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'device', 'priority', 'subject', 'keywords', 'recipient_number'
        )})
    )
    actions = None
    inlines = (fax_forms.DocumentInline, fax_forms.CoverInline)

    def get_urls(self):
        urls = super(FaxAdmin, self).get_urls()
        my_urls = patterns('',
            url(
                r'^(?P<object_id>\d+)/download/$',
                self.admin_site.admin_view(fax_views.download_pdf),
                name='fax_fax_download'
            ),
            url(
                r'^(?P<object_id>\d+)/pdf/report/$',
                self.admin_site.admin_view(fax_views.report_pdf),
                name='fax_fax_report'
            ),
            url(
                r'^(?P<object_id>\d+)/cover/download/$',
                self.admin_site.admin_view(fax_views.download_cover),
                name='fax_fax_downloadcover'
            ),
        )
        return my_urls + urls


    def has_delete_permission(self, request, obj=None):
        """
        Returns True if the given request has permission to change the given
        Django model instance.

        If `obj` is None, this should return True if the given request has
        permission to delete *any* object of the given type.
        """
        if request.user.is_superuser:
            return True

        if obj:
            if obj.can_be_delete():
                return True

        return False

    def get_subject(self, obj):
        return  obj.subject # FIXME VITTO: togliere quando scommentaate URL
        if obj.status == 8:
            return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_forward', obj.id), obj.subject)
        return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_change', obj.id), obj.subject)
    get_subject.short_description = _('Subject')
    get_subject.allow_tags = True
    get_subject.admin_order_field = 'subject'

    def get_read(self, obj):
        if not obj.documents.all():
            return ""

        txt = []
        for doc in obj.documents.all():
            image = None
            description = os.path.basename(doc.file.path) + ' '
            image = 'fax_read.png'
            if obj.status == 2: # received
                if not obj.read:
                    description +=  _('Not Read')
                    image = 'fax_unread.png'
                if obj.read == 1:
                    description += _('Read')

            txt += ["""
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url': reverse('admin:fax_fax_download', args=(obj.id,)),
                'static_url' : settings.STATIC_URL,
                'image' : image,
                'description': description
            }]
        return "".join(txt)
    get_read.short_description = _('RD')
    get_read.allow_tags = True


    def get_status(self, obj):
        if obj.status == 2:
            description = _('Received')
            image = 'fax_in.png'
        elif obj.status == 3:
            description = _('Queued')
            image = 'fax_queue.png'
        elif obj.status == 4:
            description = _('Sent')
            image = 'fax_out.png'
        elif obj.status == 5:
            description = obj.error or _('Failed')
            image = 'fax_error.png'
        elif obj.status == 6:
            description = _('Multi Queued')
            image = 'all_fax.png'
        elif obj.status == 7:
            description = _('Multi Sent')
            image = 'all_fax.png'
        elif obj.status == 8:
            description = _('To Send')
            image = 'fax_to_send.png'
        elif obj.status == 9:
            description = _('Accepted by peer')
            if obj.job:
                description += ' - id: %s' % obj.job
            image = 'fax_accepted.png'

        description =  "%s - %s" % (description or '', obj.status_message or '')

        return '<img src="%(static_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>' % {
            'static_url' : settings.STATIC_URL,
            'image' : image,
            'description': description
        }
    get_status.short_description = _('ST')
    get_status.allow_tags = True


    def get_pages(self, obj):
        return obj.pages or ""
    get_pages.short_description = _("Pag.")


    def get_notify_group(self, obj):
        return obj.notify_group or ""
    get_notify_group.short_description = _("notify group")


    def get_report(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/report.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
               'url' : reverse('admin:fax_fax_report', args=(obj.id,)),
                'static_url' : settings.STATIC_URL,
                'description': _("Report PDF")
            }
        return ""
    get_report.short_description = _("RP")
    get_report.allow_tags = True


    def get_cover(self, obj):
        if obj.has_cover():
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sjmb/images/pdf_icon.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url' : reverse('admin:fax_fax_downloadcover', args=(obj.id,)),
                'static_url' : settings.STATIC_URL,
                'description': _("Cover PDF")
            }
        return ""
    get_cover.short_description = _("CO")
    get_cover.allow_tags = True


    def forward(self, obj):
        return
        if obj.status in (2,4,5,9):
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/inoltra.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url' : reverse('admin:fax_fax_forward', obj.id),
                'static_url' : settings.STATIC_URL,
                'description': _("Forward")
            }
        return ""
    forward.short_description = _("FW")
    forward.allow_tags = True

    def save_formset(self, request, form, formset, change):
        super(FaxAdmin, self).save_formset(request, form, formset, change)

        fax = form.save()
        fax.send()

class DeviceAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_status_display', 'name', 'description', 'smtp_host', 'from_user', 'get_edit_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("General Information"), {
            'fields' : ('name', 'type', 'description')
        }),
        (_("Mail2fax Gateway"), {
            'fields' : ('from_user', ('kpn_password', 'kpn_url'),)
        }),
        (_("Mail2fax gateway - POP3 Account"), {
            'fields' : (('pop_host', 'pop_user', 'pop_password', 'pop_use_ssl'),)
        }),
        (_("Mail2fax gateway - SMTP account"), {
            'fields' : (('smtp_host', 'smtp_user', 'smtp_password', 'smtp_use_ssl', 'smtp_port'),)
        }),
    )

class FaxNumberAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = (
        'name', 'number', 'get_device', 'move_actions', 'get_edit_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("General Information"), {
            'fields' : ('status', 'ordering', 'name', 'number', 'device')
        }),
        (_("Notify Email"), {
            'fields' : ('notify_mails', 'send_at_received_fax', 'send_at_sent_fax',)
        }),
    )

    def get_device(self, obj):
        str_device = ""
        for d in obj.device.all():
            str_device += "%s | " % d.name
        return str_device
    get_device.short_description = _("Device")


admin.site.register(Fax, FaxAdmin)
admin.site.register(Device, DeviceAdmin)
admin.site.register(FaxNumber, FaxNumberAdmin)
admin.site.register(FaxPermission)

==> jmb.fax-0.3.tar.gz: jmb.fax-0.3/jmb/fax/admin.py <==
# -*- coding: utf-8 -*-

import os
from copy import copy
import datetime

from django.contrib import admin
from django.utils.translation import ugettext as _
from django import forms
from django.conf import settings
from django.core.urlresolvers import reverse
from django.conf.urls.defaults import patterns, url
import django_filters

from jmb.core.admin.options import ExtendibleModelAdmin, OrderedModelAdmin
from jmb.core.forms.widgets import DateWidget
from jmb.organization.models import Organization
from jmb.fax.models import Fax, Device, FaxNumber, FaxPermission, Document, Cover
from jmb.fax import views as fax_views, forms as fax_forms

class FaxSearchFilterset(django_filters.FilterSet):
#    date_sent = django_filters.DateRangeFilter(required=False, lookup_type='gte')
    date_sent = django_filters.CustomDateRangeFilter()
#    status__in = django_filters.MultipleChoiceFilter()
    class Meta:
        model = Fax
        fields = (
                ('status__in', 'subject__icontains'),
                ('recipient_number__icontains', 'recipient__icontains'),
                ('sender_number__icontains', 'sender__icontains'),
                ('date_sent__range', 'date_sent',),
                ('device','submitter__groups'),
                )

class FaxAdmin(ExtendibleModelAdmin):
    form = fax_forms.FaxForm
    list_title = _('List Fax')
    list_display = (
        'get_status', 'get_pages', 'sender', 'recipient', 'recipient_number', 'get_subject',
        'submitter', 'date_create', 'device',
        'get_notify_group', 'get_read', 'get_report', 'get_cover',
        'get_edit_icon', 'get_delete_icon'
    )
#    search_filterset_class = FaxSearchFilterset
    search_fields = ('recipient_number','recipient', 'sender')
    advanced_search_fields = (
                ('status__in', 'subject__icontains'),
                ('recipient_number__icontains', 'recipient__icontains'),
                ('sender_number__icontains', 'sender__icontains'),
                ('date_sent__range', ),
                ('device','submitter__groups'),
                )
    list_filter = ('device__name',)

    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'device', 'priority', 'subject', 'keywords', 'recipient_numbers'
        )})
    )
    actions = None
    inlines = (fax_forms.DocumentInline, fax_forms.CoverInline)
    ordering = ('-date_create',)

    def get_urls(self):
        urls = super(FaxAdmin, self).get_urls()
        my_urls = patterns('',
            url(
                r'^(?P<object_id>\d+)/download/$',
                self.admin_site.admin_view(fax_views.download_pdf),
                name='fax_fax_download'
            ),
            url(
                r'^(?P<object_id>\d+)/pdf/report/$',
                self.admin_site.admin_view(fax_views.report_pdf),
                name='fax_fax_report'
            ),
            url(
                r'^(?P<object_id>\d+)/cover/download/$',
                self.admin_site.admin_view(fax_views.download_cover),
                name='fax_fax_downloadcover'
            ),
        )
        return my_urls + urls


    def has_delete_permission(self, request, obj=None):
        """
        Returns True if the given request has permission to change the given
        Django model instance.

        If `obj` is None, this should return True if the given request has
        permission to delete *any* object of the given type.
        """
        if request.user.is_superuser:
            return True

        if obj:
            if obj.can_be_delete():
                return True

        return False

    def get_subject(self, obj):
        return  obj.subject # FIXME VITTO: togliere quando scommentaate URL
        if obj.status == 8:
            return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_forward', obj.id), obj.subject)
        return '<a href="%s">%s</a>' % (reverse('admin:fax_fax_change', obj.id), obj.subject)
    get_subject.short_description = _('Subject')
    get_subject.allow_tags = True
    get_subject.admin_order_field = 'subject'

    def get_read(self, obj):
        if not obj.documents.all():
            return ""

        txt = []
        for doc in obj.documents.all():
            image = None
            description = os.path.basename(doc.file.path) + ' '
            image = 'fax_read.png'
            if obj.status == 2: # received
                if not obj.read:
                    description +=  _('Not Read')
                    image = 'fax_unread.png'
                if obj.read == 1:
                    description += _('Read')

            txt += ["""
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url': reverse('admin:fax_fax_download', args=(doc.id,)),
                'static_url' : settings.STATIC_URL,
                'image' : image,
                'description': description
            }]
        return "".join(txt)
    get_read.short_description = _('RD')
    get_read.allow_tags = True


    def get_status(self, obj):
        if obj.status == 2:
            description = _('Received')
            image = 'fax_in.png'
        elif obj.status == 3:
            description = _('Queued')
            image = 'fax_queue.png'
        elif obj.status == 4:
            description = _('Sent')
            image = 'fax_out.png'
        elif obj.status == 5:
            description = obj.error or _('Failed')
            image = 'fax_error.png'
        elif obj.status == 6:
            description = _('Multi Queued')
            image = 'all_fax.png'
        elif obj.status == 7:
            description = _('Multi Sent')
            image = 'all_fax.png'
        elif obj.status == 8:
            description = _('To Send')
            image = 'fax_to_send.png'
        elif obj.status == 9:
            description = _('Accepted by peer')
            if obj.job:
                description += ' - id: %s' % obj.job
            image = 'fax_accepted.png'

        description =  "%s - %s" % (description or '', obj.status_message or '')

        return '<img src="%(static_url)sfax/images/%(image)s" alt="%(description)s" title="%(description)s"/>' % {
            'static_url' : settings.STATIC_URL,
            'image' : image,
            'description': description
        }
    get_status.short_description = _('ST')
    get_status.allow_tags = True


    def get_pages(self, obj):
        return obj.pages or ""
    get_pages.short_description = _("Pag.")


    def get_notify_group(self, obj):
        return obj.notify_group or ""
    get_notify_group.short_description = _("notify group")


    def get_report(self, obj):
        if obj.status == 2 or obj.status == 4 or obj.status == 5:
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/report.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
               'url' : reverse('admin:fax_fax_report', args=(obj.id,)),
                'static_url' : settings.STATIC_URL,
                'description': _("Report PDF")
            }
        return ""
    get_report.short_description = _("RP")
    get_report.allow_tags = True


    def get_cover(self, obj):
        if obj.has_cover():
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sjmb/images/pdf_icon.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url' : reverse('admin:fax_fax_downloadcover', args=(obj.id,)),
                'static_url' : settings.STATIC_URL,
                'description': _("Cover PDF")
            }
        return ""
    get_cover.short_description = _("CO")
    get_cover.allow_tags = True


    def forward(self, obj):
        return
        if obj.status in (2,4,5,9):
            return """
                <a href="%(url)s">
                    <img src="%(static_url)sfax/images/inoltra.png" alt="%(description)s" title="%(description)s"/>
                </a>
            """ % {
                'url' : reverse('admin:fax_fax_forward', obj.id),
                'static_url' : settings.STATIC_URL,
                'description': _("Forward")
            }
        return ""
    forward.short_description = _("FW")
    forward.allow_tags = True

    def save_formset(self, request, form, formset, change):
        super(FaxAdmin, self).save_formset(request, form, formset, change)

        fax = form.save()

        if fax.status == '3':  # 3 is default, but here I check '3', that means it comes from form
            fax.recipient_number = form.cleaned_data['recipient_numbers'] and form.cleaned_data['recipient_numbers'][0] 
            fax.recipient = form._company_names[fax.recipient_number]
            fax.submitter = request.user

        fax.save()
        if formset.model is Cover: # Document formset has already passed
            if fax.status is not None:
                return
            for num in form.cleaned_data['recipient_numbers'][1:]:
                faxnew = clone(fax)
                faxnew.recipient_number = num
                faxnew.recipient = form._company_names[faxnew.recipient_number]
                faxnew.save()
                for doc in fax.documents.all():
                    docnew = clone(doc)
                    docnew.fax = faxnew
                    docnew.save()

                if fax.has_cover():
                    new_cover = clone(fax.cover)
                    new_cover.fax = faxnew
                    new_cover.save()

                    faxnew.send()
            # Wait to send till it has the cover

            fax.send()
               

def clone(obj):
    newobj = copy(obj)
    newobj.id = None

    return newobj
        
class DeviceAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_status_display', 'name', 'description', 'smtp_host', 
        'from_user', 'get_edit_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("General Information"), {
            'fields' : ('name', 'type', 'description')
        }),
        (_("Mail2fax Gateway"), {
            'fields' : ('from_user', ('kpn_password', 'kpn_url'),)
        }),
        (_("Mail2fax gateway - POP3 Account"), {
            'fields' : (('pop_host', 'pop_user', 'pop_password', 'pop_use_ssl'),)
        }),
        (_("Mail2fax gateway - SMTP account"), {
            'fields' : (('smtp_host', 'smtp_user', 'smtp_password', 'smtp_use_ssl', 'smtp_port'),)
        }),
    )

class FaxNumberAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = (
        'name', 'number', 'get_device', 'move_actions', 'get_edit_icon', 'get_delete_icon'
    )
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("General Information"), {
            'fields' : ('status', 'ordering', 'name', 'number', 'device')
        }),
        (_("Notify Email"), {
            'fields' : ('notify_mails', 'send_at_received_fax', 'send_at_sent_fax',)
        }),
    )

    def get_device(self, obj):
        str_device = ""
        for d in obj.device.all():
            str_device += "%s | " % d.name
        return str_device
    get_device.short_description = _("Device")


admin.site.register(Fax, FaxAdmin)
admin.site.register(Device, DeviceAdmin)
admin.site.register(FaxNumber, FaxNumberAdmin)
admin.site.register(FaxPermission)
